@@ -17,10 +17,13 @@
 #include <KPropertiesDialog>
 #include <KFileItem>
 #include <KMimeTypeTrader>
-#include <KRun>
 #include <KActionCollection>
 #include <KMessageBox>
 
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
+
 #include <QDir>
 #include <QPixmap>
 #include <QDateTime>
@@ -255,25 +258,13 @@ Selector::Selector(QWidget *parent, KActionCollection *actionCollection)
   QFileInfo info(QStringLiteral("/"));
   item->setSize(info.size());
   item->setLastModified(info.lastModified());
-  item->setIcon(SmallIcon(QStringLiteral("folder")));
+  item->setIcon(QIcon::fromTheme(QStringLiteral("folder")));
   setExpanded(item->index(), true);
 
   fillTree(item, QStringLiteral("/"), false);
 
   connect(this, &Selector::expanded, this, &Selector::expandedSlot);
 
-  // for convenience, open the tree at the HOME directory
-  const char *home = ::getenv("HOME");
-  if ( home )
-  {
-    QStandardItem *homeItem = findItemByPath(QFile::decodeName(home));
-    if ( homeItem )
-    {
-      setExpanded(homeItem->index(), true);
-      scrollTo(homeItem->index());
-    }
-  }
-
   minSize = QSize(columnWidth(0) + columnWidth(1), -1);
   resizeColumnToContents(0);
   resizeColumnToContents(1);
@@ -310,6 +301,22 @@ Selector::Selector(QWidget *parent, KActionCollection *actionCollection)
 
 //--------------------------------------------------------------------------------
 
+void Selector::openHomeDir()
+{
+  const char *home = ::getenv("HOME");
+  if ( home )
+  {
+    QStandardItem *homeItem = findItemByPath(QFile::decodeName(home));
+    if ( homeItem )
+    {
+      setExpanded(homeItem->index(), true);
+      scrollTo(homeItem->index());
+    }
+  }
+}
+
+//--------------------------------------------------------------------------------
+
 QSize Selector::minimumSizeHint() const
 {
   return minSize;
@@ -359,11 +366,12 @@ void Selector::fillTree(ListItem *parent, const QString &path, bool on)
       {
         KIconEffect effect;
 
-        folderIcon = SmallIcon(QStringLiteral("folder"));
+        folderIcon = QIcon::fromTheme(QStringLiteral("folder")).pixmap(KIconLoader::SizeSmall);
         folderIconHidden = effect.apply(folderIcon, KIconEffect::DeSaturate, 0, QColor(), true);
 
-        folderLinkIcon = SmallIcon(QStringLiteral("folder"), 0, KIconLoader::DefaultState,
-                                   QStringList(QStringLiteral("emblem-symbolic-link")));
+        folderLinkIcon = KIconLoader::global()->loadIcon(QStringLiteral("folder"), KIconLoader::Small,
+                                                         0, KIconLoader::DefaultState,
+                                                         QStringList(QStringLiteral("emblem-symbolic-link")));
 
         folderLinkIconHidden = effect.apply(folderLinkIcon, KIconEffect::DeSaturate, 0, QColor(), true);
       }
@@ -383,11 +391,12 @@ void Selector::fillTree(ListItem *parent, const QString &path, bool on)
       {
         KIconEffect effect;
 
-        documentIcon = SmallIcon(QStringLiteral("text-x-generic"));
+        documentIcon = QIcon::fromTheme(QStringLiteral("text-x-generic")).pixmap(KIconLoader::SizeSmall);
         documentIconHidden = effect.apply(documentIcon, KIconEffect::DeSaturate, 0, QColor(), true);
 
-        documentLinkIcon = SmallIcon(QStringLiteral("text-x-generic"), 0, KIconLoader::DefaultState,
-                                     QStringList(QStringLiteral("emblem-symbolic-link")));
+        documentLinkIcon = KIconLoader::global()->loadIcon(QStringLiteral("text-x-generic"), KIconLoader::Small,
+                                                           0, KIconLoader::DefaultState,
+                                                           QStringList(QStringLiteral("emblem-symbolic-link")));
 
         documentLinkIconHidden = effect.apply(documentLinkIcon, KIconEffect::DeSaturate, 0, QColor(), true);
       }
@@ -670,9 +679,9 @@ void Selector::populateOpenMenu()
   KFileItem fileItem(sourceUrl);
   QString mimeType(fileItem.determineMimeType().name());
 
-  KService::List services = KMimeTypeTrader::self()->query(mimeType);
+  const KService::List services = KMimeTypeTrader::self()->query(mimeType);
 
-  foreach (const KService::Ptr &service, services)
+  for (const KService::Ptr &service : services)
   {
     QString text = service->name().replace(QLatin1Char('&'), QStringLiteral("&&"));
     QAction* action = openWithSubMenu->addAction(text);
@@ -713,8 +722,10 @@ void Selector::open()
 
   QUrl sourceUrl = QUrl::fromLocalFile(getPath(item));
 
-  KRun *run = new KRun(sourceUrl, window());  // auto-deletes itself
-  run->setRunExecutables(false);
+  auto *job = new KIO::OpenUrlJob(sourceUrl, window());
+  job->setRunExecutables(false);
+  job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+  job->start();
 }
 
 //--------------------------------------------------------------------------------
@@ -732,27 +743,27 @@ void Selector::openWith(QAction *action)
 
   if ( name.isEmpty() ) // Other Application...
   {
-    KRun::displayOpenWithDialog(QList<QUrl>() << sourceUrl, this);
+    KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob();
+    job->setUrls(QList<QUrl>() << sourceUrl);
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
     return;
   }
 
   if ( name == QLatin1String("-") )  // File Manager
   {
-#if (KIO_VERSION >= QT_VERSION_CHECK(5, 31, 0))
-    KRun::runUrl(sourceUrl.adjusted(QUrl::RemoveFilename), QStringLiteral("inode/directory"), this, KRun::RunFlags());
-#else
-    KRun::runUrl(sourceUrl.adjusted(QUrl::RemoveFilename), QStringLiteral("inode/directory"), this);
-#endif
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(sourceUrl.adjusted(QUrl::RemoveFilename), QStringLiteral("inode/directory"));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
 
     return;
   }
 
   KService::Ptr service = serviceForName[name];
-#if (KIO_VERSION >= QT_VERSION_CHECK(5, 24, 0))
-  KRun::runApplication(*service, QList<QUrl>() << sourceUrl, this);
-#else
-  KRun::run(*service, QList<QUrl>() << sourceUrl, this);
-#endif
+  KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service);
+  job->setUrls(QList<QUrl>() << sourceUrl);
+  job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+  job->start();
 }
 
 //--------------------------------------------------------------------------------
